diff -u --recursive nrpe-2.4/sample-config/nrpe.cfg.in nrpe-2.4.mod/sample-config/nrpe.cfg.in
--- sample-config/nrpe.cfg.in   2006-02-03 16:02:32.000000000 -0600
+++ sample-config/nrpe.cfg.in   2006-02-23 13:14:36.000000000 -0600
@@ -56,6 +56,18 @@
 
 nrpe_group=@nrpe_grp@
 
+# ALLOWED HOST ADDRESSES
+# This is an optional comma-delimited list of IP address or hostnames 
+# that are allowed to talk to the NRPE daemon.
+#
+# Note: The daemon only does rudimentary checking of the client's IP
+# address.  I would highly recommend adding entries in your /etc/hosts.allow
+# file to allow only the specified host to connect to the port
+# you are running this daemon on.
+#
+# NOTE: This option is ignored if NRPE is running under either inetd or xinetd
+
+#allowed_hosts=127.0.0.1,192.168.0.2
 
 
 # COMMAND ARGUMENT PROCESSING
diff -u --recursive nrpe-2.4/src/nrpe.c nrpe-2.4.mod/src/nrpe.c
--- src/nrpe.c  2006-02-22 17:51:57.000000000 -0600
+++ src/nrpe.c  2006-02-23 13:02:27.000000000 -0600
@@ -53,6 +53,7 @@
 int     socket_timeout=DEFAULT_SOCKET_TIMEOUT;
 int     command_timeout=DEFAULT_COMMAND_TIMEOUT;
 char    *command_prefix=NULL;
+char   allowed_hosts[MAX_INPUT_BUFFER];
 
 command *command_list=NULL;
 
@@ -72,6 +73,8 @@
 int     show_license=FALSE;
 int     show_version=FALSE;
 int     use_inetd=TRUE;
+int    use_allowed_hosts=FALSE;
+int    is_an_allowed_host(char *);
 int     debug=FALSE;
 
 
@@ -443,6 +446,16 @@
                         server_address[sizeof(server_address)-1]='\0';
                         }
 
+                else if(!strcmp(varname,"allowed_hosts")){
+                        if(strlen(input_buffer)>sizeof(allowed_hosts)){
+                                syslog(LOG_ERR,"Allowed hosts list too long in config file '%s' - Line %d\n",filename,line);
+                                return ERROR;
+                                }
+                        strncpy(allowed_hosts,varvalue,sizeof(allowed_hosts));
+                        allowed_hosts[sizeof(allowed_hosts)-1]='\x0';
+                       use_allowed_hosts=TRUE;
+                        }
+
                else if(strstr(input_line,"command[")){
                        temp_buffer=strtok(varname,"[");
                        temp_buffer=strtok(NULL,"]");
@@ -685,6 +698,9 @@
 #endif
 
        syslog(LOG_INFO,"Listening for connections on port %d\n",htons(myname.sin_port));
+       if(use_allowed_hosts==TRUE)
+               syslog(LOG_INFO,"Allowing connections from: %s\n",allowed_hosts);
+
 
        /* listen for connection requests - fork() if we get one */
        while(1){
@@ -786,6 +802,33 @@
                                if(debug==TRUE)
                                        syslog(LOG_DEBUG,"Connection from %s port %d",inet_ntoa(nptr->sin_addr),nptr->sin_port);
 
+                                /* is this is a blessed machine? */
+                               if(use_allowed_hosts==TRUE) {
+                                       snprintf(connecting_host,sizeof(connecting_host),"%s",inet_ntoa(nptr->sin_addr));
+                                       connecting_host[sizeof(connecting_host)-1]='\x0';
+
+                                       if(!is_an_allowed_host(connecting_host)){
+
+                                               /* log error to syslog facility */
+                                               syslog(LOG_ERR,"Host %s is not allowed to talk to us!",connecting_host);
+
+                                               /* log info to syslog facility */
+                                                       if(debug==TRUE)
+                                                               syslog(LOG_DEBUG,"Connection from %s closed.",connecting_host);
+
+                                                       /* close socket prior to exiting */
+                                               close(new_sd);
+
+                                                       exit(STATE_OK);
+                                               }
+                                       else{
+
+                                               /* log info to syslog facility */
+                                               if(debug==TRUE)
+                                                       syslog(LOG_DEBUG,"Host address is in allowed_hosts");
+                                               }
+                                       }
+
 #ifdef HAVE_LIBWRAP
 
                                /* Check whether or not connections are allowed from this host */
@@ -1761,3 +1804,53 @@
        return OK;
         }
 
+/* checks to see if a given host is allowed to talk to us */
+int is_an_allowed_host(char *connecting_host){
+       char temp_buffer[MAX_INPUT_BUFFER];
+       char *temp_ptr;
+       int result=0;
+        struct hostent *myhost;
+       char **pptr;
+       char resolved_addr[INET6_ADDRSTRLEN];
+
+       /* try and match IP addresses first */
+       strncpy(temp_buffer,allowed_hosts,sizeof(temp_buffer));
+       temp_buffer[sizeof(temp_buffer)-1]='\x0';
+
+       for(temp_ptr=strtok(temp_buffer,",");temp_ptr!=NULL;temp_ptr=strtok(NULL,",")){
+
+               if(!strcmp(connecting_host,temp_ptr)){
+                       result=1;
+                       break;
+                       }
+               }
+
+       /* try DNS lookups if needed */
+       if(result==0){
+
+               strncpy(temp_buffer,allowed_hosts,sizeof(temp_buffer));
+               temp_buffer[sizeof(temp_buffer)-1]='\x0';
+
+               for(temp_ptr=strtok(temp_buffer,",");temp_ptr!=NULL;temp_ptr=strtok(NULL,",")){
+
+                       myhost=gethostbyname(temp_ptr);
+                       if(myhost!=NULL){
+
+                               /* check all addresses for the host... */
+                               for(pptr=myhost->h_addr_list;*pptr!=NULL;pptr++){
+
+                                       inet_ntop(myhost->h_addrtype,*pptr,resolved_addr,sizeof(resolved_addr));
+                                       if(!strcmp(resolved_addr,connecting_host)){
+                                               result=1;
+                                               break;
+                                               }
+                                       }
+                               }
+
+                       if(result==1)
+                               break;
+                       }
+               }
+
+       return result;
+        }